pub struct AddressGroupsCommand { /* private fields */ }Expand description
Lists address groups that the project has access to.
Default policy settings return only the address groups owned by the project of the user submitting the request, unless the user has administrative role.
Standard query parameters are supported on the URI. For more information, see Filtering and Column Selection.
Use the fields query parameter to control which fields are returned in
the response body. For more information, see Fields.
Pagination query parameters are supported if Neutron configuration supports
it by overriding allow_pagination=false. For more information, see
Pagination.
Sorting query parameters are supported if Neutron configuration supports it
with allow_sorting=true. For more information, see Sorting.
Normal response codes: 200
Error response codes: 401
Implementations
Sourceimpl AddressGroupsCommand
impl AddressGroupsCommand
Sourcepub async fn take_action<C: CliArgs>(
&self,
parsed_args: &C,
client: &mut AsyncOpenStack,
) -> Result<(), OpenStackCliError>
pub async fn take_action<C: CliArgs>( &self, parsed_args: &C, client: &mut AsyncOpenStack, ) -> Result<(), OpenStackCliError>
Perform command action