Module show

Module show 

Show Extension command

Wraps invoking of the v2.0/extensions/{id} with GET method

Structs

ExtensionCommand
Shows details for an extension, by alias. The response shows the extension name and its alias. To show details for an extension, you specify the alias.