pub struct FloatingipsCommand { /* private fields */ }Expand description
Lists floating IPs visible to the user.
Default policy settings return only the floating IPs owned by the user’s project, unless the user has admin role.
Standard query parameters are supported on the URI. For more information, see Filtering and Column Selection.
Use the fields query parameter to control which fields are returned in
the response body. For more information, see Fields.
Pagination query parameters are supported if Neutron configuration supports
it by overriding allow_pagination=false. For more information, see
Pagination.
Sorting query parameters are supported if Neutron configuration supports it
with allow_sorting=true. For more information, see Sorting.
This example request lists floating IPs in JSON format:
Normal response codes: 200
Error response codes: 401
Implementations
Sourceimpl FloatingipsCommand
impl FloatingipsCommand
Sourcepub async fn take_action<C: CliArgs>(
&self,
parsed_args: &C,
client: &mut AsyncOpenStack,
) -> Result<(), OpenStackCliError>
pub async fn take_action<C: CliArgs>( &self, parsed_args: &C, client: &mut AsyncOpenStack, ) -> Result<(), OpenStackCliError>
Perform command action