pub struct PortCommand { /* private fields */ }Expand description
Updates a port.
You can update information for a port, such as its symbolic name and
associated IPs. When you update IPs for a port, any previously associated
IPs are removed, returned to the respective subnet allocation pools, and
replaced by the IPs in the request body. Therefore, this operation replaces
the fixed_ip attribute when you specify it in the request body. If the
updated IP addresses are not valid or are already in use, the operation
fails and the existing IP addresses are not removed from the port.
When you update security groups for a port and the operation succeeds, any
associated security groups are removed and replaced by the security groups
in the request body. Therefore, this operation replaces the
security_groups attribute when you specify it in the request body. If the
security groups are not valid, the operation fails and the existing
security groups are not removed from the port.
When you update binding:profile of a port with null it is treated as {}
in the response.
The binding:vnic_type attribute can be updated on unbound ports only. If
the port is already bound, the update operation of the attribute returns
the Conflict (409) response code.
Only admins and users with a specific role can update the data plane status
(default role: data_plane_integrator).
Normal response codes: 200
Error response codes: 400, 401, 403, 404, 409, 412
Implementations
Sourceimpl PortCommand
impl PortCommand
Sourcepub async fn take_action<C: CliArgs>(
&self,
parsed_args: &C,
client: &mut AsyncOpenStack,
) -> Result<(), OpenStackCliError>
pub async fn take_action<C: CliArgs>( &self, parsed_args: &C, client: &mut AsyncOpenStack, ) -> Result<(), OpenStackCliError>
Perform command action