pub struct SecurityGroupsCommand { /* private fields */ }Expand description
Lists OpenStack Networking security groups to which the project has access.
The response is an array of security_group objects which contains a list
of security_group_rules objects.
Standard query parameters are supported on the URI. For more information, see Filtering and Column Selection.
Use the fields query parameter to control which fields are returned in
the response body. For more information, see Fields.
Pagination query parameters are supported if Neutron configuration supports
it by overriding allow_pagination=false. For more information, see
Pagination.
Sorting query parameters are supported if Neutron configuration supports it
with allow_sorting=true. For more information, see Sorting.
Normal response codes: 200
Error response codes: 401
Implementations
Sourceimpl SecurityGroupsCommand
impl SecurityGroupsCommand
Sourcepub async fn take_action<C: CliArgs>(
&self,
parsed_args: &C,
client: &mut AsyncOpenStack,
) -> Result<(), OpenStackCliError>
pub async fn take_action<C: CliArgs>( &self, parsed_args: &C, client: &mut AsyncOpenStack, ) -> Result<(), OpenStackCliError>
Perform command action