Module ikepolicy

Module ikepolicy 

Ikepolicy commands

Modules

create
Create Ikepolicy command
delete
Delete Ikepolicy command
list
List Ikepolicies command
set
Set Ikepolicy command
show
Show Ikepolicy command

Structs

IkepolicyCommand
The Internet Key Exchange (IKE) policy that identifies the authentication and encryption algorithm to use during phase one and two negotiation of a VPN connection.

Enums

IkepolicyCommands
Supported subcommands