pub struct FlavorCommand { /* private fields */ }Expand description
Creates a flavor.
This operation establishes a new flavor.
The service_type to which the flavor applies is a required parameter. The corresponding service plugin must have been activated as part of the configuration. Check Service providers for how to see currently loaded service types. Additionally the service plugin needs to support the use of flavors.
Creation currently limited to administrators. Other users will receive a
Forbidden 403 response code with a response body NeutronError message
expressing that creation is disallowed by policy.
Until one or more service profiles are associated with the flavor by the
operator, attempts to use the flavor during resource creations will
currently return a Not Found 404 with a response body that indicates no
service profile could be found.
If the API cannot fulfill the request due to insufficient data or data that
is not valid, the service returns the HTTP Bad Request (400) response
code with information about the failure in the response body. Validation
errors require that you correct the error and submit the request again.
Normal response codes: 201
Error response codes: 400, 401, 403, 404
Implementations
Sourceimpl FlavorCommand
impl FlavorCommand
Sourcepub async fn take_action<C: CliArgs>(
&self,
parsed_args: &C,
client: &mut AsyncOpenStack,
) -> Result<(), OpenStackCliError>
pub async fn take_action<C: CliArgs>( &self, parsed_args: &C, client: &mut AsyncOpenStack, ) -> Result<(), OpenStackCliError>
Perform command action