pub struct FloatingipCommand { /* private fields */ }Expand description
Creates a floating IP, and, if you specify port information, associates the floating IP with an internal port.
To associate the floating IP with an internal port, specify the port ID attribute in the request body. If you do not specify a port ID in the request, you can issue a PUT request instead of a POST request.
Default policy settings enable only administrative users to set floating IP addresses and some non-administrative users might require a floating IP address. If you do not specify a floating IP address in the request, the operation automatically allocates one.
By default, this operation associates the floating IP address with a single
fixed IP address that is configured on an OpenStack Networking port. If a
port has multiple IP addresses, you must specify the fixed_ip_address
attribute in the request body to associate a fixed IP address with the
floating IP address.
You can create floating IPs on only external networks. When you create a floating IP, you must specify the ID of the network on which you want to create the floating IP. Alternatively, you can create a floating IP on a subnet in the external network, based on the costs and quality of that subnet.
You must configure an IP address with the internal OpenStack Networking port that is associated with the floating IP address.
The operation returns the Bad Request (400) response code for one of
reasons:
If the port ID is not valid, this operation returns 404 response code.
The operation returns the Conflict (409) response code for one of
reasons:
Normal response codes: 201
Error response codes: 400, 401, 404, 409
Implementations
Sourceimpl FloatingipCommand
impl FloatingipCommand
Sourcepub async fn take_action<C: CliArgs>(
&self,
parsed_args: &C,
client: &mut AsyncOpenStack,
) -> Result<(), OpenStackCliError>
pub async fn take_action<C: CliArgs>( &self, parsed_args: &C, client: &mut AsyncOpenStack, ) -> Result<(), OpenStackCliError>
Perform command action